@@ -179,4 +179,25 @@ mod tests {
             .unwrap()
         );
     }
+
+    #[derive(Debug, Ltv, Default, PartialEq, Eq)]
+    #[object(id = 1, length_size = 1)]
+    struct ItemWithList {
+        #[ltv_field_list(1)]
+        pub items: Vec<u8>,
+    }
+
+    #[test]
+    fn item_with_list() {
+        let obj = ItemWithList {
+            items: vec![1, 2, 3, 4, 5, 6],
+        };
+
+        let bytes = &ltv::get_ltv::<_, { ByteOrder::BE }>(&obj);
+
+        assert_eq!(
+            obj,
+            <ItemWithList as LTVItem<{ ByteOrder::BE }>>::from_ltv(10, bytes).unwrap()
+        );
+    }
 }
